@@ -10,6 +10,8 @@ from allianceauth.services.hooks import get_extension_logger
 
 from buybackprogram.app_settings import (
     BUYBACKPROGRAM_PRICE_AGE_WARNING_LIMIT,
+    BUYBACKPROGRAM_PRICE_JANICE_API_KEY,
+    BUYBACKPROGRAM_PRICE_METHOD,
     BUYBACKPROGRAM_PRICE_SOURCE_ID,
     BUYBACKPROGRAM_TRACKING_PREFILL,
 )
@@ -36,6 +38,7 @@ from buybackprogram.notes import (
     note_refined_price_used,
     note_unpublished_item,
 )
+from buybackprogram.tasks import valid_janice_api_key
 
 logger = get_extension_logger(__name__)
 
@@ -72,18 +75,48 @@ def get_or_create_prices(item_id):
 
     except ItemPrices.DoesNotExist:
 
-        response_fuzzwork = requests.get(
-            "https://market.fuzzwork.co.uk/aggregates/",
-            params={
-                "types": item_id,
-                "station": BUYBACKPROGRAM_PRICE_SOURCE_ID,
-            },
-        )
+        if BUYBACKPROGRAM_PRICE_METHOD == "Fuzzwork":
+            response_fuzzwork = requests.get(
+                "https://market.fuzzwork.co.uk/aggregates/",
+                params={
+                    "types": item_id,
+                    "station": BUYBACKPROGRAM_PRICE_SOURCE_ID,
+                },
+            )
 
-        items_fuzzwork = response_fuzzwork.json()
+            items_fuzzwork = response_fuzzwork.json()
+
+            buy = int(float(items_fuzzwork[str(item_id)]["buy"]["max"]))
+            sell = int(float(items_fuzzwork[str(item_id)]["sell"]["min"]))
+
+        elif BUYBACKPROGRAM_PRICE_METHOD == "Janice":
+            if valid_janice_api_key():
+                response_janice = requests.get(
+                    f"https://janice.e-351.com/api/rest/v2/pricer/{item_id}",
+                    headers={
+                        "Content-Type": "text/plain",
+                        "X-ApiKey": BUYBACKPROGRAM_PRICE_JANICE_API_KEY,
+                        "accept": "application/json",
+                    },
+                )
+
+                item_janice = response_janice.json()
+
+                buy = int(float(item_janice["top5AveragePrices"]["buyPrice5DayMedian"]))
+                sell = int(
+                    float(item_janice["top5AveragePrices"]["sellPrice5DayMedian"])
+                )
+            else:
+                logger.error(
+                    "Price setup failed for Janice, invalid API key! Provide a working key or change price source to Fuzzwork"
+                )
+
+                buy = False
+                sell = False
+
+        else:
+            raise f"Unknown pricing method: {BUYBACKPROGRAM_PRICE_METHOD}"
 
-        buy = int(float(items_fuzzwork[str(item_id)]["buy"]["max"]))
-        sell = int(float(items_fuzzwork[str(item_id)]["sell"]["min"]))
         updated = timezone.now()
 
         try:
@@ -232,6 +265,13 @@ def get_item_prices(item_type, name, quantity, program):
 
         notes.append(note_unpublished_item(item_type))
 
+        logger.debug(
+            "%s published status is %s and market group is %s, item disallowed: %s"
+            % (name, item_type.published, item_type.eve_market_group, item_disallowed)
+        )
+
+    logger.debug("%s is disallowed: %s" % (name, item_disallowed))
+
     if not item_disallowed:
 
         # If raw ore value should not be taken into account
