@@ -705,7 +705,7 @@ class Owner(models.Model):
 
 
 class Location(models.Model):
-    """ Location where the buyback program is operated at """
+    """Location where the buyback program is operated at"""
 
     name = models.CharField(
         max_length=32, help_text="Structure name where the contracts are accepted at"
@@ -757,6 +757,13 @@ class Location(models.Model):
 class Program(models.Model):
     """An Eve Online buyback program"""
 
+    class Expiration(models.TextChoices):
+        DAY1 = "1 Day", _("1 Day")
+        DAY3 = "3 Days", _("3 Days")
+        WEEK1 = "1 Week", _("1 Week")
+        WEEK2 = "2 Weeks", _("2 Weeks")
+        WEEK4 = "4 Weeks", _("4 Weeks")
+
     name = models.CharField(
         verbose_name="Name/description",
         max_length=64,
@@ -784,6 +791,13 @@ class Program(models.Model):
         related_name="+",
     )
 
+    expiration = models.CharField(
+        max_length=7,
+        choices=Expiration.choices,
+        default=Expiration.WEEK2,
+        help_text="Expiration time the contracts should bet set to.",
+    )
+
     tax = models.IntegerField(
         verbose_name="Default tax",
         default=0,
